aboutsummaryrefslogtreecommitdiff
path: root/bpkg/package-skeleton.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bpkg/package-skeleton.hxx')
-rw-r--r--bpkg/package-skeleton.hxx11
1 files changed, 7 insertions, 4 deletions
diff --git a/bpkg/package-skeleton.hxx b/bpkg/package-skeleton.hxx
index 0b573e4..d2a848c 100644
--- a/bpkg/package-skeleton.hxx
+++ b/bpkg/package-skeleton.hxx
@@ -10,6 +10,7 @@
#include <bpkg/utility.hxx>
#include <bpkg/package.hxx>
+#include <bpkg/common-options.hxx>
namespace bpkg
{
@@ -28,13 +29,14 @@ namespace bpkg
// If the package is not external, then none of the root directories
// should be specified.
//
// Note that the database and available_package are expected to outlive
// this object.
//
// Note also that this creates an "unloaded" skeleton and is therefore
- // cheap.
+ // relatively cheap.
//
- package_skeleton (database&,
+ package_skeleton (const common_options& co,
+ database&,
const available_package&,
strings config_vars,
optional<dir_path> src_root,
@@ -90,6 +92,7 @@ namespace bpkg
private:
// NOTE: remember to update move/copy constructors!
//
+ const common_options* co_;
database* db_;
const available_package* available_;
strings config_vars_;
@@ -28,13 +29,14 @@ namespace bpkg
// should be specified.
//
- // Note that the database and available_package are expected to outlive
- // this object.
+ // Note that the options, database, and available_package are expected to
+ // outlive this object.
//
// Note also that this creates an "unloaded" skeleton and is therefore